@@ -66,7 +66,8 @@ int main(int argc, char *argv[])
 			count = parse_keys(packets, &keys);
 			logthing(LOGTHING_NOTICE, "Received %d keys.",
 				count);
-			printf("Storing %d keys.\n", count);
+			printf("Key block added to key server database.\n");
+			printf("  New public keys added: %d\n", count);
 			end_html();
 			if (stdout != NULL && fileno(stdout) != -1) {
 				fclose(stdout);
@@ -76,13 +77,13 @@ int main(int argc, char *argv[])
 				fclose(stderr);
 			}
 			catchsignals();
-			initdb(false);
+			config.dbbackend->initdb(false);
 			
 			count = cleankeys(keys);
 			logthing(LOGTHING_INFO, "%d keys cleaned.",
 					count);
 
-			count = update_keys(&keys, true);
+			count = config.dbbackend->update_keys(&keys, true);
 			logthing(LOGTHING_NOTICE, "Got %d new keys.",
 				count);
 
@@ -91,7 +92,7 @@ int main(int argc, char *argv[])
 				keys = NULL;
 			}
 			
-			cleanupdb();
+			config.dbbackend->cleanupdb();
 		} else {
 			puts("No OpenPGP packets found in input.");
 			end_html();
